<?php
/**
 * Maps for tabs element.
 *
 * @package Elements.
 */

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

if ( ! function_exists( 'cheshalo_get_vc_map_tabs' ) ) {
	/**
	 * Displays the shortcode settings fields in the admin.
	 */
	function cheshalo_get_vc_map_tabs() {
		$typography = cheshalo_get_typography_map(
			array(
				'title'    => esc_html__( 'Title typography', 'cheshalo' ),
				'group'    => esc_html__( 'General', 'cheshalo' ),
				'key'      => 'heading_title',
				'selector' => '{{WRAPPER}}.wd-tabs .tabs-name',
			)
		);

		$secondary_font = cheshalo_get_opt( 'secondary-font' );
		$primary_font   = cheshalo_get_opt( 'primary-font' );
		$text_font      = cheshalo_get_opt( 'text-font' );

		$secondary_font_title = isset( $secondary_font[0] ) ? esc_html__( 'Secondary font', 'cheshalo' ) . ' (' . $secondary_font[0]['font-family'] . ')' : esc_html__( 'Secondary font', 'cheshalo' );
		$text_font_title      = isset( $text_font[0] ) ? esc_html__( 'Text font', 'cheshalo' ) . ' (' . $text_font[0]['font-family'] . ')' : esc_html__( 'Text', 'cheshalo' );
		$primary_font_title   = isset( $primary_font[0] ) ? esc_html__( 'Title font', 'cheshalo' ) . ' (' . $primary_font[0]['font-family'] . ')' : esc_html__( 'Title font', 'cheshalo' );

		return array(
			'base'            => 'cheshalo_tabs',
			'name'            => esc_html__( 'Tabs', 'cheshalo' ),
			'description'     => esc_html__( 'Tabbed content', 'cheshalo' ),
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/tabs.svg',
			'as_parent'       => array( 'only' => 'cheshalo_tab' ),
			'content_element' => true,
			'js_view'         => 'VcColumnView',
			'default_content' => '[cheshalo_tab title="Tab #1"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/cheshalo_tab][cheshalo_tab title="Tab #2"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo. 2[/cheshalo_tab]',
			'params'          => array(
				array(
					'param_name' => 'cheshalo_css_id',
					'type'       => 'cheshalo_css_id',
					'group'      => esc_html__( 'General', 'cheshalo' ),
				),
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Heading', 'cheshalo' ),
					'group'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'title_divider',
				),
				array(
					'heading'          => esc_html__( 'Design', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'cheshalo_image_select',
					'param_name'       => 'design',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Simple', 'cheshalo' ) => 'simple',
						esc_html__( 'Alternative', 'cheshalo' ) => 'alt',
						esc_html__( 'Aside', 'cheshalo' ) => 'aside',
					),
					'images_value'     => array(
						'default' => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/default.png',
						'simple'  => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/simple.png',
						'alt'     => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/alternative.png',
						'aside'   => CHESHALO_ASSETS_IMAGES . '/settings/ajax-tabs/aside.png',
					),
					'std'              => 'default',
					'wood_tooltip'     => true,
					'edit_field_class' => 'vc_col-xs-12 vc_column tab-design',
				),
				array(
					'heading'          => esc_html__( 'Title color', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'tabs_title_color',
					'selectors'        => array(
						'{{WRAPPER}} .tabs-name' => array(
							'color: {{VALUE}};',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				$typography['font_family'],
				$typography['font_size'],
				$typography['font_weight'],
				$typography['text_transform'],
				$typography['font_style'],
				$typography['line_height'],
				array(
					'heading'          => esc_html__( 'Description color', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'tabs_description_color',
					'selectors'        => array(
						'{{WRAPPER}} .wd-tabs-desc' => array(
							'color: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'default', 'aside' ),
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'heading'          => esc_html__( 'Border color', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'tabs_border_color',
					'selectors'        => array(
						'{{WRAPPER}}.wd-tabs.tabs-design-simple .tabs-name' => array(
							'border-color: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'simple' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'wd_slider',
					'param_name'       => 'tabs_side_width',
					'heading'          => esc_html__( 'Side heading width', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'devices'          => array(
						'desktop' => array(
							'unit' => 'px',
						),
					),
					'range'            => array(
						'px' => array(
							'min'  => 100,
							'max'  => 500,
							'step' => 1,
						),
						'%'  => array(
							'min'  => 0,
							'max'  => 100,
							'step' => 1,
						),
					),
					'selectors'        => array(
						'{{WRAPPER}} .wd-tabs.tabs-design-aside' => array(
							'--wd-side-width: {{VALUE}}{{UNIT}};',
						),
					),
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'aside' ),
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'heading'          => esc_html__( 'Heading background', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'cheshalo_switch',
					'param_name'       => 'enable_heading_bg',
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'heading'          => esc_html__( 'Custom background color', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'heading_bg',
					'selectors'        => array(
						'{{WRAPPER}}.wd-tabs.wd-header-with-bg .wd-tabs-header' => array(
							'background-color:{{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'enable_heading_bg',
						'value'   => array( 'yes' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'group'       => esc_html__( 'General', 'cheshalo' ),
					'type'       => 'cheshalo_empty_space',
					'param_name' => 'cheshalo_empty_space',
				),
				array(
					'param_name'       => 'tabs_title_alignment',
					'type'             => 'cheshalo_image_select',
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value'     => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'std'              => 'center',
					'dependency'       => array(
						'element' => 'design',
						'value'   => array( 'default' ),
					),
					'wood_tooltip'     => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				/**
				 * Title
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Heading content', 'cheshalo' ),
					'group'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'title_divider',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Title', 'cheshalo' ),
					'group'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'title',
				),
				array(
					'type'       => 'textarea',
					'heading'    => esc_html__( 'Description', 'cheshalo' ),
					'group'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'description',
					'dependency' => array(
						'element' => 'design',
						'value'   => array( 'default', 'aside' ),
					),
				),
				/**
				 * Image
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Icon settings', 'cheshalo' ),
					'group'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'image_divider',
				),
				array(
					'type'             => 'attach_image',
					'heading'          => esc_html__( 'Icon image', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'param_name'       => 'image',
					'value'            => '',
					'hint'             => esc_html__( 'Select image from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Images size', 'cheshalo' ),
					'group'            => esc_html__( 'General', 'cheshalo' ),
					'param_name'       => 'img_size',
					'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'description'      => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
				),
				/**
				 * Tabs Layout.
				 */
				array(
					'param_name' => 'tabs_layout_divider',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Layout', 'cheshalo' ),
					'group'      => esc_html__( 'Tab title', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'param_name'       => 'tabs_style',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Style', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Underline', 'cheshalo' ) => 'underline',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'icon_position',
					'type'             => 'cheshalo_image_select',
					'heading'          => esc_html__( 'Icon position', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Top', 'cheshalo' ) => 'top',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images_value'     => array(
						'top'   => CHESHALO_ASSETS_IMAGES . '/settings/infobox/position/top.png',
						'left'  => CHESHALO_ASSETS_IMAGES . '/settings/infobox/position/left.png',
						'right' => CHESHALO_ASSETS_IMAGES . '/settings/infobox/position/right.png',
					),
					'std'              => 'left',
					'wood_tooltip'     => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'type'             => 'wd_slider',
					'param_name'       => 'tabs_title_space_between_vertical',
					'heading'          => esc_html__( 'Vertical spacing', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'devices'          => array(
						'desktop' => array(
							'unit' => 'px',
						),
						'tablet'  => array(
							'unit' => 'px',
						),
						'mobile'  => array(
							'unit' => 'px',
						),
					),
					'range'            => array(
						'px' => array(
							'min'  => 0,
							'max'  => 150,
							'step' => 1,
						),
					),
					'selectors'        => array(
						'body {{WRAPPER}}.wd-tabs' => array(
							'--wd-header-sp: {{VALUE}}{{UNIT}};',
						),
					),
					'dependency'       => array(
						'element'            => 'design',
						'value_not_equal_to' => array( 'aside' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'wd_slider',
					'param_name'       => 'tabs_title_space_between_horizontal',
					'heading'          => esc_html__( 'Horizontal spacing', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'devices'          => array(
						'desktop' => array(
							'unit' => 'px',
						),
						'tablet'  => array(
							'unit' => 'px',
						),
						'mobile'  => array(
							'unit' => 'px',
						),
					),
					'range'            => array(
						'px' => array(
							'min'  => 0,
							'max'  => 150,
							'step' => 1,
						),
					),
					'selectors'        => array(
						'{{WRAPPER}} .wd-nav-tabs > li:not(:last-child)' => array(
							'margin-inline-end: {{VALUE}}{{UNIT}};',
						),
					),
					'dependency'       => array(
						'element'            => 'design',
						'value_not_equal_to' => array( 'aside' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				 * Tabs Typography.
				 */
				array(
					'param_name' => 'tabs_layout_divider',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Typography', 'cheshalo' ),
					'group'      => esc_html__( 'Tab title', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'param_name'       => 'tabs_title_font_family',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Font family', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						$primary_font_title   => 'primary',
						$text_font_title      => 'text',
						$secondary_font_title => 'alt',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_font_weight',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Font weight', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						'' => '',
						esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
						esc_html__( 'Light 200', 'cheshalo' ) => 200,
						esc_html__( 'Book 300', 'cheshalo' ) => 300,
						esc_html__( 'Normal 400', 'cheshalo' ) => 400,
						esc_html__( 'Medium 500', 'cheshalo' ) => 500,
						esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
						esc_html__( 'Bold 700', 'cheshalo' ) => 700,
						esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
						esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
					),
					'std'              => 600,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_font_size',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Predefined size', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Small (16px)', 'cheshalo' ) => 's',
						esc_html__( 'Extra Small (14px)', 'cheshalo' ) => 'xs',
						esc_html__( 'Medium (18px)', 'cheshalo' ) => 'm',
						esc_html__( 'Large (22px)', 'cheshalo' ) => 'l',
						esc_html__( 'Extra Large (26px)', 'cheshalo' ) => 'xl',
						esc_html__( 'Custom', 'cheshalo' ) => 'custom',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_custom_font_size',
					'type'             => 'cheshalo_responsive_size',
					'heading'          => esc_html__( 'Custom font size', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'css_args'         => array(
						'font-size' => array(
							' .wd-fontsize-custom',
						),
					),
					'dependency'       => array(
						'element' => 'tabs_title_font_size',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_line_height',
					'type'             => 'cheshalo_responsive_size',
					'heading'          => esc_html__( 'Custom line height', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'css_args'         => array(
						'line-height' => array(
							' .wd-fontsize-custom',
						),
					),
					'dependency'       => array(
						'element' => 'tabs_title_font_size',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_color_scheme',
					'type'             => 'cheshalo_dropdown',
					'heading'          => esc_html__( 'Color scheme', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Dark', 'cheshalo' ) => 'dark',
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Custom', 'cheshalo' ) => 'custom',
					),
					'style'            => array(
						'dark' => '#2d2a2a',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_title_text_color',
					'type'             => 'cheshalo_colorpicker',
					'heading'          => esc_html__( 'Text color', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'css_args'         => array(
						'color' => array(
							' .wd-nav > li > a',
						),
					),
					'dependency'       => array(
						'element' => 'tabs_title_color_scheme',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_text_hover_color',
					'type'             => 'cheshalo_colorpicker',
					'heading'          => esc_html__( 'Text hover color', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'css_args'         => array(
						'color' => array(
							' .wd-nav > li:hover > a',
						),
					),
					'dependency'       => array(
						'element' => 'tabs_title_color_scheme',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_text_active_color',
					'type'             => 'cheshalo_colorpicker',
					'heading'          => esc_html__( 'Text active color', 'cheshalo' ),
					'group'            => esc_html__( 'Tab title', 'cheshalo' ),
					'css_args'         => array(
						'color' => array(
							'.wd-tabs:not(.wd-inited) .wd-nav-tabs li:first-child a',
							' .wd-nav-tabs > li.wd-active > a',
						),
					),
					'dependency'       => array(
						'element' => 'tabs_title_color_scheme',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				/**
				 * Content Settings.
				 */
				array(
					'param_name' => 'content_typography_divider',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Typography', 'cheshalo' ),
					'group'      => esc_html__( 'Content', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'param_name'       => 'content_font_family',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Font family', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						$primary_font_title   => 'primary',
						$text_font_title      => 'text',
						$secondary_font_title => 'alt',
					),
					'std'              => '',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'content_font_size',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Predefined size', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Small (16px)', 'cheshalo' ) => 's',
						esc_html__( 'Extra Small (14px)', 'cheshalo' ) => 'xs',
						esc_html__( 'Medium (18px)', 'cheshalo' ) => 'm',
						esc_html__( 'Large (22px)', 'cheshalo' ) => 'l',
						esc_html__( 'Extra Large (26px)', 'cheshalo' ) => 'xl',
						esc_html__( 'Custom', 'cheshalo' ) => 'custom',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'content_custom_font_size',
					'type'             => 'cheshalo_responsive_size',
					'heading'          => esc_html__( 'Custom font size', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'css_args'         => array(
						'font-size' => array(
							' .wd-fontsize-custom',
						),
					),
					'dependency'       => array(
						'element' => 'content_font_size',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'content_line_height',
					'type'             => 'cheshalo_responsive_size',
					'heading'          => esc_html__( 'Custom line height', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'css_args'         => array(
						'line-height' => array(
							' .wd-fontsize-custom',
						),
					),
					'dependency'       => array(
						'element' => 'content_font_size',
						'value'   => array( 'custom' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'content_font_weight',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Font weight', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
						esc_html__( 'Light 200', 'cheshalo' ) => 200,
						esc_html__( 'Book 300', 'cheshalo' ) => 300,
						esc_html__( 'Normal 400', 'cheshalo' ) => 400,
						esc_html__( 'Medium 500', 'cheshalo' ) => 500,
						esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
						esc_html__( 'Bold 700', 'cheshalo' ) => 700,
						esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
						esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'content_text_color_scheme',
					'type'             => 'cheshalo_dropdown',
					'heading'          => esc_html__( 'Color scheme', 'cheshalo' ),
					'group'            => esc_html__( 'Content', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Dark', 'cheshalo' ) => 'dark',
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Custom', 'cheshalo' ) => 'custom',
					),
					'style'            => array(
						'dark' => '#2d2a2a',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name' => 'content_text_color_custom',
					'type'       => 'cheshalo_colorpicker',
					'heading'    => esc_html__( 'Custom Color', 'cheshalo' ),
					'group'      => esc_html__( 'Content', 'cheshalo' ),
					'css_args'   => array(
						'color' => array(
							' .wd-tab-content',
						),
					),
					'dependency' => array(
						'element' => 'content_text_color_scheme',
						'value'   => array( 'custom' ),
					),

				),

				/**
				 * Design Options.
				 */
				array(
					'type'       => 'css_editor',
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
				),
				cheshalo_get_vc_responsive_spacing_map(),

				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),

				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Theme Animation', 'cheshalo' ),
					'hint'             => esc_html__( 'Use custom theme animations if you want to run them in the slider element.', 'cheshalo' ),
					'param_name'       => 'wd_animation',
					'group'            => esc_html__( 'Advanced', 'cheshalo' ),
					'admin_label'      => true,
					'value'            => array(
						esc_html__( 'None', 'cheshalo' )       => '',
						esc_html__( 'Slide from top', 'cheshalo' ) => 'slide-from-top',
						esc_html__( 'Slide from bottom', 'cheshalo' ) => 'slide-from-bottom',
						esc_html__( 'Slide from left', 'cheshalo' ) => 'slide-from-left',
						esc_html__( 'Slide from right', 'cheshalo' ) => 'slide-from-right',
						esc_html__( 'Slide short from left', 'cheshalo' ) => 'slide-short-from-left',
						esc_html__( 'Slide short from right', 'cheshalo' ) => 'slide-short-from-right',
						esc_html__( 'Flip X bottom', 'cheshalo' ) => 'bottom-flip-x',
						esc_html__( 'Flip X top', 'cheshalo' ) => 'top-flip-x',
						esc_html__( 'Flip Y left', 'cheshalo' ) => 'left-flip-y',
						esc_html__( 'Flip Y right', 'cheshalo' ) => 'right-flip-y',
						esc_html__( 'Zoom in', 'cheshalo' )    => 'zoom-in',
					),
					'std'              => '',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Theme Animation Delay (ms)', 'cheshalo' ),
					'param_name'       => 'wd_animation_delay',
					'group'            => esc_html__( 'Advanced', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
					'dependency'       => array(
						'element'            => 'wd_animation',
						'value_not_equal_to' => array( '' ),
					),
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Theme Animation duration', 'cheshalo' ),
					'param_name'       => 'wd_animation_duration',
					'group'            => esc_html__( 'Advanced', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
					'value'            => array(
						esc_html__( 'Slow', 'cheshalo' )   => 'slow',
						esc_html__( 'Normal', 'cheshalo' ) => 'normal',
						esc_html__( 'Fast', 'cheshalo' )   => 'fast',
					),
					'dependency'       => array(
						'element'            => 'wd_animation',
						'value_not_equal_to' => array( '' ),
					),
					'std'              => 'normal',
				),

				cheshalo_get_vc_responsive_visible_map( 'responsive_tabs_hide' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_desktop' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_tablet' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_mobile' ),
			),
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_tab' ) ) {
	function cheshalo_get_vc_map_tab() {
		return array(
			'base'            => 'cheshalo_tab',
			'name'            => esc_html__( 'Tab', 'cheshalo' ),
			'description'     => esc_html__( 'Add tab in tabs area', 'cheshalo' ),
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/tab.svg',
			'as_child'        => array( 'only' => 'cheshalo_tabs' ),
			'content_element' => true,
			'params'          => array(
				/**
				 * Title.
				 */
				array(
					'param_name' => 'title',
					'type'       => 'textarea',
					'holder'     => 'div',
					'heading'    => esc_html__( 'Title', 'cheshalo' ),
				),
				/**
				 * Content.
				 */
				array(
					'param_name' => 'tabs_content_divider',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Content', 'cheshalo' ),
				),
				array(
					'param_name'       => 'content_type',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Content type', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Text', 'cheshalo' ) => 'text',
						esc_html__( 'HTML Block', 'cheshalo' ) => 'html_block',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name' => 'content',
					'type'       => 'textarea_html',
					'heading'    => esc_html__( 'Content', 'cheshalo' ),
					'dependency' => array(
						'element' => 'content_type',
						'value'   => array( 'text' ),
					),
				),
				array(
					'param_name' => 'html_block_id',
					'type'       => 'cheshalo_dropdown',
					'heading'    => esc_html__( 'Select block', 'cheshalo' ),
					'callback'   => 'cheshalo_get_html_blocks_array_with_empty',
					'dependency' => array(
						'element' => 'content_type',
						'value'   => array( 'html_block' ),
					),
				),

				/**
				 * Icon.
				 */
				array(
					'param_name' => 'icon_divider',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Icon settings', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'param_name'       => 'tabs_title_icon_type',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'List type', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'With icon', 'cheshalo' ) => 'icon',
						esc_html__( 'With image', 'cheshalo' ) => 'image',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_image',
					'type'             => 'attach_image',
					'heading'          => esc_html__( 'Image', 'cheshalo' ),
					'value'            => '',
					'dependency'       => array(
						'element' => 'tabs_title_icon_type',
						'value'   => array( 'image' ),
					),
					'hint'             => esc_html__( 'Select image from media library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_image_size',
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Image size', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'tabs_title_icon_type',
						'value'   => array( 'image' ),
					),
					'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'thumbnail\' size.', 'cheshalo' ),
					'description'      => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\' or enter image size in pixels: \'200x100\'.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name'       => 'tabs_icon_libraries',
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Icon library', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'Font Awesome', 'cheshalo' ) => 'fontawesome',
						esc_html__( 'Open Iconic', 'cheshalo' )  => 'openiconic',
						esc_html__( 'Typicons', 'cheshalo' )     => 'typicons',
						esc_html__( 'Entypo', 'cheshalo' )       => 'entypo',
						esc_html__( 'Linecons', 'cheshalo' )     => 'linecons',
						esc_html__( 'Mono Social', 'cheshalo' )  => 'monosocial',
						esc_html__( 'Material', 'cheshalo' )     => 'material',
					),
					'dependency'       => array(
						'element' => 'tabs_title_icon_type',
						'value'   => 'icon',
					),
					'hint'             => esc_html__( 'Select icon library.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'param_name' => 'icon_fontawesome',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'fontawesome',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'param_name' => 'icon_openiconic',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'openiconic',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'openiconic',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'param_name' => 'icon_typicons',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'typicons',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'typicons',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'param_name' => 'icon_entypo',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'entypo',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'entypo',
					),
				),
				array(
					'param_name' => 'icon_linecons',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'linecons',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'linecons',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'param_name' => 'icon_monosocial',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'monosocial',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'monosocial',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
				array(
					'param_name' => 'icon_material',
					'type'       => 'iconpicker',
					'heading'    => esc_html__( 'Icon', 'cheshalo' ),
					'settings'   => array(
						'emptyIcon'    => true,
						'type'         => 'material',
						'iconsPerPage' => 50,
					),
					'dependency' => array(
						'element' => 'tabs_icon_libraries',
						'value'   => 'material',
					),
					'hint'       => esc_html__( 'Select icon from library.', 'cheshalo' ),
				),
			),
		);
	}
}

if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
	/**
	 * Create cheshalo tabs wrapper.
	 */
	class WPBakeryShortCode_cheshalo_tabs extends WPBakeryShortCodesContainer {}
}
