<?php

namespace XTS\Modules\Header_Builder\Elements;

use XTS\Modules\Header_Builder\Element;

/**
 * ------------------------------------------------------------------------------------------------
 *  Compare icon in the header elements
 * ------------------------------------------------------------------------------------------------
 */

class Compare extends Element {

	public function __construct() {
		parent::__construct();

		$this->template_name = 'compare';
	}

	public function map() {
		$this->args = array(
			'type'            => 'compare',
			'title'           => esc_html__( 'Compare', 'cheshalo' ),
			'text'            => esc_html__( 'Compare icon', 'cheshalo' ),
			'icon'            => 'xts-i-compare',
			'editable'        => true,
			'container'       => false,
			'edit_on_create'  => true,
			'drag_target_for' => array(),
			'drag_source'     => 'content_element',
			'removable'       => true,
			'addable'         => true,
			'params'          => array(
				'design'                 => array(
					'id'          => 'design',
					'title'       => esc_html__( 'Display', 'cheshalo' ),
					'type'        => 'selector',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'value'       => 'icon',
					'options'     => array(
						'icon' => array(
							'value' => 'icon',
							'label' => esc_html__( 'Icon', 'cheshalo' ),
						),
						'text' => array(
							'value' => 'text',
							'label' => esc_html__( 'Icon with text', 'cheshalo' ),
						),
					),
					'description' => esc_html__( 'You can show the icon only or display "Compare" text too.', 'cheshalo' ),
				),
				'icon_design'            => array(
					'id'      => 'icon_design',
					'title'   => esc_html__( 'Icon design', 'cheshalo' ),
					'type'    => 'selector',
					'tab'     => esc_html__( 'Style', 'cheshalo' ),
					'group'   => esc_html__( 'Icon', 'cheshalo' ),
					'value'   => '2',
					'options' => array(
						'1' => array(
							'value' => '1',
							'label' => esc_html__( 'First', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/first.jpg',
						),
						'2' => array(
							'value' => '2',
							'label' => esc_html__( 'Second', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/second.jpg',
						),
						'4' => array(
							'value' => '4',
							'label' => esc_html__( 'Third', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/third.jpg',
						),
						'6' => array(
							'value' => '6',
							'label' => esc_html__( 'Fourth', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/fourth.jpg',
						),
						'7' => array(
							'value' => '7',
							'label' => esc_html__( 'Fifth', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/fifth.jpg',
						),
						'8' => array(
							'value' => '8',
							'label' => esc_html__( 'Sixth', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/sixth.jpg',
						),
					),
				),
				'wrap_type'              => array(
					'id'       => 'wrap_type',
					'title'    => esc_html__( 'Background wrap type', 'cheshalo' ),
					'type'     => 'selector',
					'tab'      => esc_html__( 'Style', 'cheshalo' ),
					'group'    => esc_html__( 'Icon', 'cheshalo' ),
					'value'    => 'icon_only',
					'options'  => array(
						'icon_only'     => array(
							'value' => 'icon_only',
							'label' => esc_html__( 'Icon only', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/bg-wrap-type/compare-wrap-icon.jpg',
						),
						'icon_and_text' => array(
							'value' => 'icon_and_text',
							'label' => esc_html__( 'Icon and text', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/bg-wrap-type/compare-wrap-icon-and-text.jpg',
						),
					),
					'requires' => array(
						'design'      => array(
							'comparison' => 'equal',
							'value'      => 'text',
						),
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => array( '6', '7' ),
						),
					),
				),
				'color'                  => array(
					'id'          => 'color',
					'title'       => esc_html__( 'Color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'whb-row .{{WRAPPER}}.wd-tools-element .wd-tools-inner, .whb-row .{{WRAPPER}}.wd-tools-element > a > .wd-tools-icon' => array(
							'color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => array( '7', '8' ),
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'hover_color'            => array(
					'id'          => 'hover_color',
					'title'       => esc_html__( 'Hover color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'whb-row .{{WRAPPER}}.wd-tools-element:hover .wd-tools-inner, .whb-row .{{WRAPPER}}.wd-tools-element:hover > a > .wd-tools-icon' => array(
							'color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => array( '7', '8' ),
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'bg_color'               => array(
					'id'          => 'bg_color',
					'title'       => esc_html__( 'Background color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'whb-row .{{WRAPPER}}.wd-tools-element .wd-tools-inner, .whb-row .{{WRAPPER}}.wd-tools-element > a > .wd-tools-icon' => array(
							'background-color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => array( '7', '8' ),
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'bg_hover_color'         => array(
					'id'          => 'bg_hover_color',
					'title'       => esc_html__( 'Hover background color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'whb-row .{{WRAPPER}}.wd-tools-element:hover .wd-tools-inner, .whb-row .{{WRAPPER}}.wd-tools-element:hover > a > .wd-tools-icon' => array(
							'background-color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => array( '7', '8' ),
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'icon_color'             => array(
					'id'          => 'icon_color',
					'title'       => esc_html__( 'Icon color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'{{WRAPPER}}.wd-tools-element.wd-design-8 .wd-tools-icon' => array(
							'color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => '8',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'icon_hover_color'       => array(
					'id'          => 'icon_hover_color',
					'title'       => esc_html__( 'Hover icon color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'{{WRAPPER}}.wd-tools-element.wd-design-8:hover .wd-tools-icon' => array(
							'color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => '8',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'icon_bg_color'          => array(
					'id'          => 'icon_bg_color',
					'title'       => esc_html__( 'Icon background color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'{{WRAPPER}}.wd-tools-element.wd-design-8 .wd-tools-icon' => array(
							'background-color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => '8',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'icon_bg_hover_color'    => array(
					'id'          => 'icon_bg_hover_color',
					'title'       => esc_html__( 'Hover icon background color', 'cheshalo' ),
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'type'        => 'color',
					'value'       => '',
					'selectors'   => array(
						'{{WRAPPER}}.wd-tools-element.wd-design-8:hover .wd-tools-icon' => array(
							'background-color: {{VALUE}};',
						),
					),
					'requires'    => array(
						'icon_design' => array(
							'comparison' => 'equal',
							'value'      => '8',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'icon_type'              => array(
					'id'          => 'icon_type',
					'title'       => esc_html__( 'Icon type', 'cheshalo' ),
					'type'        => 'selector',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'value'       => 'default',
					'options'     => array(
						'default' => array(
							'value' => 'default',
							'label' => esc_html__( 'Default', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/compare-icons/second.jpg',
						),
						'custom'  => array(
							'value' => 'custom',
							'label' => esc_html__( 'Custom', 'cheshalo' ),
							'image' => CHESHALO_ASSETS_IMAGES . '/header-builder/upload.jpg',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'custom_icon'            => array(
					'id'          => 'custom_icon',
					'title'       => esc_html__( 'Upload an image', 'cheshalo' ),
					'type'        => 'image',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Icon', 'cheshalo' ),
					'value'       => '',
					'description' => '',
					'requires'    => array(
						'icon_type' => array(
							'comparison' => 'equal',
							'value'      => 'custom',
						),
					),
					'extra_class' => 'xts-col-6',
				),
				'hide_product_count'     => array(
					'id'          => 'hide_product_count',
					'title'       => esc_html__( 'Hide product count label', 'cheshalo' ),
					'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_compare_hide_product_count.mp4" autoplay loop muted></video>',
					'type'        => 'switcher',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Extra', 'cheshalo' ),
					'value'       => false,
					'description' => esc_html__( 'Mark this option if you want to hide product count label.', 'cheshalo' ),
				),
				'show_dropdown_category' => array(
					'id'          => 'show_dropdown_category',
					'title'       => esc_html__( 'Show dropdown with category', 'cheshalo' ),
					'hint'        => '<video src="' . CHESHALO_TOOLTIP_URL . 'hb_compare_show_dropdown_category.mp4" autoplay loop muted></video>',
					'type'        => 'switcher',
					'tab'         => esc_html__( 'Style', 'cheshalo' ),
					'group'       => esc_html__( 'Extra', 'cheshalo' ),
					'description' => esc_html__( 'Following option work only if "Compare by category" is enabled in theme settings.', 'cheshalo' ),
					'value'       => false,
				),
			),
		);
	}
}
