<?php
/**
 * Product brands map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_single_product_brands' ) ) {
	/**
	 * Product brands map.
	 */
	function cheshalo_get_vc_map_single_product_brands() {
		$typography = cheshalo_get_typography_map(
			array(
				'key'        => 'tabs_title',
				'selector'   => '{{WRAPPER}} .wd-label',
				'dependency' => array(
					'element' => 'show_label',
					'value'   => 'yes',
				),
			)
		);

		return array(
			'base'        => 'cheshalo_single_product_brands',
			'name'        => esc_html__( 'Product brands', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Single product elements', 'cheshalo' ), 'single_product' ),
			'description' => esc_html__( 'Brands assigned to the product', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-brands.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				// Label.
				array(
					'title'      => esc_html__( 'Label', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'label_divider',
				),

				array(
					'heading'          => esc_html__( 'Show label', 'cheshalo' ),
					'type'             => 'cheshalo_switch',
					'param_name'       => 'show_label',
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Label text', 'cheshalo' ),
					'type'             => 'textfield',
					'param_name'       => 'label_text',
					'value'            => esc_html__( 'Brands: ', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'show_label',
						'value'   => 'yes',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Label color', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'color',
					'selectors'        => array(
						'{{WRAPPER}} .wd-label' => array(
							'color: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'show_label',
						'value'   => 'yes',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$typography['font_family'],
				$typography['font_size'],
				$typography['font_weight'],
				$typography['text_transform'],
				$typography['font_style'],
				$typography['line_height'],

				// General.
				array(
					'title'      => esc_html__( 'General', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'label_divider',
				),

				array(
					'heading'          => esc_html__( 'Layout', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'layout',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' )  => 'default',
						esc_html__( 'Justify', 'cheshalo' )  => 'justify',
						esc_html__( 'Inline', 'cheshalo' )   => 'inline',
					),
					'dependency'       => array(
						'element'            => 'show_label',
						'value_not_equal_to' => 'no',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'alignment',
					'style'            => 'images',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'left',
						),
					),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' )   => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' )  => 'right',
					),
					'images'           => array(
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				// Image.
				array(
					'title'      => esc_html__( 'Image', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'label_divider',
				),

				array(
					'heading'    => esc_html__( 'Style', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'dropdown',
					'param_name' => 'style',
					'value'      => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Shadow', 'cheshalo' )  => 'shadow',
					),
				),

				array(
					'heading'    => esc_html__( 'Width', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'wd_slider',
					'param_name' => 'vertical_gap',
					'selectors'  => array(
						'{{WRAPPER}} img' => array(
							'max-width: {{VALUE}}{{UNIT}};',
						),
					),
					'devices'    => array(
						'desktop' => array(
							'value' => '',
							'unit'  => 'px',
						),
						'tablet'  => array(
							'value' => '',
							'unit'  => 'px',
						),
						'mobile'  => array(
							'value' => '',
							'unit'  => 'px',
						),
					),
					'range'      => array(
						'px' => array(
							'min'  => 0,
							'max'  => 300,
							'step' => 1,
						),
					),
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
